#AsyncWebsocketStreamInterface
Exchange one normal asynchronous websocket connection to unlimited number of data streams.
The websocket dictionary messages are processed well.

Application:https://github.com/monk-after-90s/HuobiAsyncWebsocket.git